#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 0.8.0
id: bower-json-0.8.0-8b42e3c4c7a9d2be40ca375bc2b9432c
key: bower_67JB9kSMNHMGCNOMerdnpl
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
author: Harry Garrood
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/bower-json-0.8.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/bower-json-0.8.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/bower-json-0.8.0
hs-libraries: HSbower-json-0.8.0-67JB9kSMNHMGCNOMerdnpl
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    aeson-better-errors-0.9.0.1-05a0fea2071afcbbba2c9016d32723d2
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
